@@ -11,6 +11,7 @@ def test_select(graph):
 
 def test_first(graph):
     assert graph.select(V(2).knows).first in (1, 5)
+    assert 2 <= graph.select(V(1).knows).first <= 4
 
 
 def test_intersection(graph):
@@ -27,8 +28,14 @@ def test_union(graph):
 
 def test_difference(graph):
     assert list(graph.select(V(1).knows).difference(V().knows(1))) == [4]
+    assert list(graph.select(V(1).knows).difference(V(2).knows)) == [2, 3, 4]
 
 
-def test_count_and_limit(graph):
+def test_count(graph):
     assert graph.select(V(1).knows).count == 3
+    assert graph.select(V(2).knows).count == 2
+
+
+def test_limit(graph):
     assert len(list(graph.select(V(1).knows).limit(2))) == 2
+    assert len(list(graph.select(V(2).knows).limit(1))) == 1
